==> A.hppa1.0-hp-hpux11.00.tar.gz: A.hppa1.0-hp-hpux11.00/dbgcf.h <==

#define HOST_CPU "hppa1.0"
#define HOST_VENDOR "hp"
#define HOST_OS "hpux11.00"
#define HOST_OS_NAME "hpux11"
#define HOST_OS_VERSION "11.00"
#define HOST_ARCH "9000/802"
#define HOST_NAME "short"
#define USER_NAME "ezk"
#define CONFIG_DATE "Mon Oct 19 20:53:29 PDT 1998"
#define PACKAGE "am-utils"
#define VERSION "6.0b1"
#define PACKAGE "am-utils"
#define VERSION "6.0b1"
#define HAVE_LIBRPCSVC 1
#define HAVE_LIBNSL 1
#define STDC_HEADERS 1
#define HAVE_WAIT3 1
#define HAVE___SETERR_REPLY 1
#define HAVE_BCMP 1
#define HAVE_BCOPY 1
#define HAVE_BZERO 1
#define HAVE_CLNT_CREATE 1
#define HAVE_CLNT_SPCREATEERROR 1
#define HAVE_GET_MYADDRESS 1
#define HAVE_GETCWD 1
#define HAVE_GETDOMAINNAME 1
#define HAVE_GETDTABLESIZE 1
#define HAVE_GETHOSTNAME 1
#define HAVE_GETPAGESIZE 1
#define HAVE_GETTIMEOFDAY 1
#define HAVE_HASMNTOPT 1
#define HAVE_MEMCMP 1
#define HAVE_MEMCPY 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMSET 1
#define HAVE_MKDIR 1
#define HAVE_MKSTEMP 1
#define HAVE_MOUNT 1
#define HAVE_PLOCK 1
#define HAVE_REGCOMP 1
#define HAVE_REGEXEC 1
#define HAVE_RMDIR 1
#define HAVE_SELECT 1
#define HAVE_SETRESUID 1
#define HAVE_SETSID 1
#define HAVE_SIGACTION 1
#define HAVE_SIGNAL 1
#define HAVE_SOCKET 1
#define HAVE_STRCHR 1
#define HAVE_STRCSPN 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRERROR 1
#define HAVE_STRSPN 1
#define HAVE_STRSTR 1
#define HAVE_SVC_GETREQ 1
#define HAVE_SVC_GETREQSET 1
#define HAVE_SYSFS 1
#define HAVE_SYSLOG 1
#define HAVE_UNAME 1
#define HAVE_UMOUNT 1
#define HAVE_VFORK 1
#define HAVE_VFSMOUNT 1
#define HAVE_WAIT3 1
#define HAVE_WAITPID 1
#define HAVE_CLNT_SPERRNO 1
#define HAVE_HASMNTOPT 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRSTR 1
#define HAVE_UALARM 1
#define HAVE_XDR_DIRPATH 1
#define HAVE_XDR_EXPORTNODE 1
#define HAVE_XDR_EXPORTS 1
#define HAVE_XDR_FHANDLE 1
#define HAVE_XDR_FHSTATUS 1
#define HAVE_XDR_GROUPNODE 1
#define HAVE_XDR_GROUPS 1
#define HAVE_XDR_MOUNTBODY 1
#define HAVE_XDR_MOUNTLIST 1
#define HAVE_XDR_MOUNTRES3 1
#define HAVE_XDR_NAME 1
#define HAVE_XDR_POINTER 1
#define HAVE_DIRENT_H 1
#define STDC_HEADERS 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_ARPA_NAMESER_H 1
#define HAVE_ARPA_INET_H 1
#define HAVE_NET_IF_H 1
#define HAVE_NET_ROUTE_H 1
#define HAVE_NETINET_IF_ETHER_H 1
#define HAVE_NETINET_IN_H 1
#define HAVE_NFS_NFS_H 1
#define HAVE_RPC_AUTH_DES_H 1
#define HAVE_RPC_PMAP_CLNT_H 1
#define HAVE_RPC_PMAP_PROT_H 1
#define HAVE_RPC_RPC_H 1
#define HAVE_RPC_TYPES_H 1
#define HAVE_RPC_XDR_H 1
#define HAVE_RPCSVC_MOUNT_H 1
#define HAVE_RPCSVC_NIS_H 1
#define HAVE_RPCSVC_YP_PROT_H 1
#define HAVE_RPCSVC_YPCLNT_H 1
#define HAVE_SYS_DIR_H 1
#define HAVE_SYS_ERRNO_H 1
#define HAVE_SYS_FILE_H 1
#define HAVE_SYS_FSTYP_H 1
#define HAVE_SYS_IOCTL_H 1
#define HAVE_SYS_LOCK_H 1
#define HAVE_SYS_MBUF_H 1
#define HAVE_SYS_MOUNT_H 1
#define HAVE_SYS_NETCONFIG_H 1
#define HAVE_SYS_PARAM_H 1
#define HAVE_SYS_PROC_H 1
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_SYS_SEMA_H 1
#define HAVE_SYS_SIGNAL_H 1
#define HAVE_SYS_SOCKET_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_SYSCALL_H 1
#define HAVE_SYS_TIME_H 1
#define HAVE_SYS_TIUSER_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_UIO_H 1
#define HAVE_SYS_UTSNAME_H 1
#define HAVE_SYS_VFS_H 1
#define HAVE_SYS_VNODE_H 1
#define HAVE_ASSERT_H 1
#define HAVE_CTYPE_H 1
#define HAVE_ERRNO_H 1
#define HAVE_FCNTL_H 1
#define HAVE_GRP_H 1
#define HAVE_LIBGEN_H 1
#define HAVE_MALLOC_H 1
#define HAVE_MEMORY_H 1
#define HAVE_MNTENT_H 1
#define HAVE_NDBM_H 1
#define HAVE_NETCONFIG_H 1
#define HAVE_NETDB_H 1
#define HAVE_NETDIR_H 1
#define HAVE_NSSWITCH_H 1
#define HAVE_PWD_H 1
#define HAVE_REGEX_H 1
#define HAVE_RESOLV_H 1
#define HAVE_SETJMP_H 1
#define HAVE_SIGNAL_H 1
#define HAVE_STDARG_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STDIO_H 1
#define HAVE_STRING_H 1
#define HAVE_STRINGS_H 1
#define HAVE_SYSLOG_H 1
#define HAVE_TIME_H 1
#define HAVE_TIUSER_H 1
#define HAVE_VARARGS_H 1
#define HAVE_UNISTD_H 1
#define TIME_WITH_SYS_TIME 1
#define HAVE_ST_RDEV 1
#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_hpux11.h"
#define HAVE_STRUCT_MNTENT 1
#define HAVE_STRUCT_NFS_ARGS 1
#define nfs_args_t struct nfs_args
#define NFS_FH_FIELD fh
#define am_nfs_fh nfs_fh
#define am_nfs_fh3 nfs_fh3
#define GETGROUPS_T gid_t
#define RETSIGTYPE void
#define HAVE_FHANDLE 1
#define MTYPE_TYPE char *
#define MTYPE_PRINTF_TYPE "%s"
#define YP_ORDER_OUTORDER_TYPE unsigned long
#define RECVFROM_FROMLEN_TYPE int
#define AUTH_CREATE_GIDLIST_TYPE gid_t
#define SVC_IN_ARG_TYPE caddr_t
#define cdfs_args_t struct cdfs_args
#define ufs_args_t struct ufs_args
#define XDRPROC_T_TYPE xdrproc_t
#define WORDS_BIGENDIAN 1
#define inline 
#define voidp void *
#define HAVE_EXTERN_OPTARG 1
#define HAVE_EXTERN_CLNT_SPERRNO 1
#define HAVE_EXTERN_FREE 1
#define HAVE_EXTERN_GETDTABLESIZE 1
#define HAVE_EXTERN_GETHOSTNAME 1
#define HAVE_EXTERN_GETLOGIN 1
#define HAVE_EXTERN_GETPAGESIZE 1
#define HAVE_EXTERN_GETWD 1
#define HAVE_EXTERN_MKSTEMP 1
#define HAVE_EXTERN_SBRK 1
#define HAVE_EXTERN_STRCASECMP 1
#define HAVE_EXTERN_STRDUP 1
#define HAVE_EXTERN_STRSTR 1
#define HAVE_EXTERN_UALARM 1
#define HAVE_EXTERN_USLEEP 1
#define HAVE_EXTERN_WAIT3 1
#define HAVE_LONG_FILE_NAMES 1
#define HAVE_TRANSPORT_TYPE_TLI 1
#define HAVE_FIELD_MNTENT_T_MNT_CNODE 1
#define HAVE_FIELD_MNTENT_T_MNT_TIME 1
#define HAVE_FIELD_CDFS_ARGS_T_FSPEC 1
#define HAVE_FIELD_UFS_ARGS_T_FLAGS 1
#define HAVE_FIELD_UFS_ARGS_T_FSPEC 1
#define HAVE_FIELD_STRUCT_FHSTATUS_FHS_FH 1
#define HAVE_FIELD_NFS_ARGS_T_ACDIRMIN 1
#define HAVE_FIELD_NFS_ARGS_T_ACREGMIN 1
#define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
#define HAVE_MAP_FILE 1
#define HAVE_MAP_NDBM 1
#define HAVE_MAP_NIS 1
#define HAVE_MAP_NISPLUS 1
#define HAVE_MAP_PASSWD 1
#define HAVE_MAP_UNION 1
#define HAVE_FS_CDFS 1
#define HAVE_FS_LOFS 1
#define HAVE_FS_NFS 1
#define HAVE_FS_UFS 1
#define HAVE_AM_FS_AUTO 1
#define HAVE_AM_FS_DIRECT 1
#define HAVE_AM_FS_TOPLVL 1
#define HAVE_AM_FS_ERROR 1
#define HAVE_AM_FS_INHERIT 1
#define HAVE_AM_FS_PROGRAM 1
#define HAVE_AM_FS_LINK 1
#define HAVE_AM_FS_LINKX 1
#define HAVE_AM_FS_HOST 1
#define HAVE_AM_FS_NFSX 1
#define HAVE_AM_FS_NFSL 1
#define HAVE_AM_FS_UNION 1
#define MOUNT_TYPE_NFS MNTTYPE_NFS
#define MOUNT_TYPE_UFS MNTTYPE_43
#define MOUNT_TYPE_CDFS MNTTYPE_CDFS
#define MOUNT_TYPE_LOFS MNTTYPE_LOFS
#define MOUNT_TYPE_CACHEFS MNTTYPE_CACHEFS
#define MOUNT_TYPE_IGNORE MNTTYPE_IGNORE
#define MNTTAB_TYPE_NFS "nfs"
#define MNTTAB_TYPE_UFS "ufs"
#define MNTTAB_TYPE_CDFS "cdfs"
#define MNTTAB_TYPE_LOFS "lofs"
#define MNTTAB_TYPE_CACHEFS "cachefs"
#define MNTTAB_OPT_ACDIRMAX "acdirmax"
#define MNTTAB_OPT_ACDIRMIN "acdirmin"
#define MNTTAB_OPT_ACREGMAX "acregmax"
#define MNTTAB_OPT_ACREGMIN "acregmin"
#define MNTTAB_OPT_ACTIMEO "actimeo"
#define MNTTAB_OPT_INTR "intr"
#define MNTTAB_OPT_NOAC "noac"
#define MNTTAB_OPT_NOAUTO "noauto"
#define MNTTAB_OPT_NOCTO "nocto"
#define MNTTAB_OPT_NOSUID "nosuid"
#define MNTTAB_OPT_PORT "port"
#define MNTTAB_OPT_RETRANS "retrans"
#define MNTTAB_OPT_RETRY "retry"
#define MNTTAB_OPT_RO "ro"
#define MNTTAB_OPT_RSIZE "rsize"
#define MNTTAB_OPT_RW "rw"
#define MNTTAB_OPT_SOFT "soft"
#define MNTTAB_OPT_SUID "suid"
#define MNTTAB_OPT_TIMEO "timeo"
#define MNTTAB_OPT_WSIZE "wsize"
#define MNT2_GEN_OPT_DATA 0x8
#define MNT2_GEN_OPT_FSS 0x0
#define MNT2_GEN_OPT_NOSUID 0x2
#define MNT2_GEN_OPT_OVERLAY 0x80
#define MNT2_GEN_OPT_QUOTA 0x4
#define MNT2_GEN_OPT_RDONLY 0x1
#define MNT2_NFS_OPT_ACDIRMAX 0x800
#define MNT2_NFS_OPT_ACDIRMIN 0x400
#define MNT2_NFS_OPT_ACREGMAX 0x200
#define MNT2_NFS_OPT_ACREGMIN 0x100
#define MNT2_NFS_OPT_FSNAME 0x1000000
#define MNT2_NFS_OPT_GRPID 0x8000
#define MNT2_NFS_OPT_HOSTNAME 0x20
#define MNT2_NFS_OPT_INT 0x40
#define MNT2_NFS_OPT_KNCONF 0x4000
#define MNT2_NFS_OPT_NOAC 0x80
#define MNT2_NFS_OPT_NOCTO 0x2000
#define MNT2_NFS_OPT_POSIX 0x40000
#define MNT2_NFS_OPT_RETRANS 0x10
#define MNT2_NFS_OPT_RSIZE 0x4
#define MNT2_NFS_OPT_SOFT 0x1
#define MNT2_NFS_OPT_TIMEO 0x8
#define MNT2_NFS_OPT_WSIZE 0x2
#define HIDE_MOUNT_TYPE "ignore"
#define MOUNT_TABLE_ON_FILE 1
#define MNTTAB_FILE_NAME "/etc/mnttab"

==> A.hppa1.1-hp-hpux11.00.tar.gz: A.hppa1.1-hp-hpux11.00/dbgcf.h <==

#define PACKAGE_NAME "am-utils"
#define PACKAGE_TARNAME "am-utils"
#define PACKAGE_VERSION "6.1b3-pre"
#define PACKAGE_STRING "am-utils 6.1b3-pre"
#define PACKAGE_BUGREPORT "amd-dev@am-utils.org"
#define HOST_CPU "hppa1.1"
#define HOST_VENDOR "hp"
#define HOST_OS "hpux11.00"
#define HOST_OS_NAME "hpux11"
#define HOST_OS_VERSION "11.00"
#define HOST_ARCH "9000/735"
#define HOST_NAME "a-hpux11.fsl.cs.sunysb.edu"
#define USER_NAME "ezk"
#define CONFIG_DATE "Sat Aug  2 14:17:34 EDT 2003"
#define PACKAGE_NAME "am-utils"
#define PACKAGE_VERSION "6.1b3-pre"
#define PACKAGE_BUGREPORT "amd-dev@am-utils.org"
#define PACKAGE "am-utils"
#define VERSION "6.1b3-pre"
#define DEBUG 1
#define STDC_HEADERS 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STRING_H 1
#define HAVE_MEMORY_H 1
#define HAVE_STRINGS_H 1
#define HAVE_INTTYPES_H 1
#define HAVE_UNISTD_H 1
#define HAVE_DLFCN_H 1
#define HOST_HEADER_VERSION "11.00"
#define HAVE_LIBRPCSVC 1
#define HAVE_LIBRT 1
#define HAVE_ALLOCA_H 1
#define HAVE_ALLOCA 1
#define HAVE_UNISTD_H 1
#define HAVE_FORK 1
#define HAVE_VFORK 1
#define HAVE_WORKING_VFORK 1
#define HAVE_WORKING_FORK 1
#define HAVE_WAIT3 1
#define GETPGRP_VOID 1
#define SETPGRP_VOID 1
#define HAVE___SETERR_REPLY 1
#define HAVE_BCMP 1
#define HAVE_BCOPY 1
#define HAVE_BZERO 1
#define HAVE_CLNT_CREATE 1
#define HAVE_CLNT_CREATE_VERS 1
#define HAVE_CLNT_SPCREATEERROR 1
#define HAVE_GET_MYADDRESS 1
#define HAVE_GETCWD 1
#define HAVE_GETDOMAINNAME 1
#define HAVE_GETDTABLESIZE 1
#define HAVE_GETHOSTNAME 1
#define HAVE_GETPAGESIZE 1
#define HAVE_HASMNTOPT 1
#define HAVE_MEMCMP 1
#define HAVE_MEMCPY 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMSET 1
#define HAVE_MKDIR 1
#define HAVE_MKSTEMP 1
#define HAVE_MLOCKALL 1
#define HAVE_MOUNT 1
#define HAVE_PLOCK 1
#define HAVE_REGCOMP 1
#define HAVE_REGEXEC 1
#define HAVE_RMDIR 1
#define HAVE_SETRESUID 1
#define HAVE_SETSID 1
#define HAVE_SIGACTION 1
#define HAVE_SIGNAL 1
#define HAVE_SOCKET 1
#define HAVE_STRCHR 1
#define HAVE_STRCSPN 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRERROR 1
#define HAVE_STRSPN 1
#define HAVE_STRSTR 1
#define HAVE_SVC_GETREQ 1
#define HAVE_SVC_GETREQSET 1
#define HAVE_SYSFS 1
#define HAVE_SYSLOG 1
#define HAVE_UNAME 1
#define HAVE_UMOUNT 1
#define HAVE_VFORK 1
#define HAVE_VFSMOUNT 1
#define HAVE_VSNPRINTF 1
#define HAVE_WAIT3 1
#define HAVE_WAITPID 1
#define HAVE_CLNT_SPERRNO 1
#define HAVE_HASMNTOPT 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRERROR 1
#define HAVE_STRSTR 1
#define HAVE_UALARM 1
#define HAVE_XDR_DIRPATH 1
#define HAVE_XDR_EXPORTNODE 1
#define HAVE_XDR_EXPORTS 1
#define HAVE_XDR_FHANDLE 1
#define HAVE_XDR_FHSTATUS 1
#define HAVE_XDR_GROUPNODE 1
#define HAVE_XDR_GROUPS 1
#define HAVE_XDR_MOUNTBODY 1
#define HAVE_XDR_MOUNTLIST 1
#define HAVE_XDR_MOUNTRES3 1
#define HAVE_XDR_NAME 1
#define HAVE_XDR_POINTER 1
#define HAVE_DIRENT_H 1
#define STDC_HEADERS 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_ARPA_NAMESER_H 1
#define HAVE_ARPA_INET_H 1
#define HAVE_NET_IF_H 1
#define HAVE_NET_ROUTE_H 1
#define HAVE_NETINET_IF_ETHER_H 1
#define HAVE_NETINET_IN_H 1
#define HAVE_NFS_NFS_H 1
#define HAVE_RPC_AUTH_DES_H 1
#define HAVE_RPC_PMAP_CLNT_H 1
#define HAVE_RPC_PMAP_PROT_H 1
#define HAVE_RPC_RPC_H 1
#define HAVE_RPC_TYPES_H 1
#define HAVE_RPC_XDR_H 1
#define HAVE_RPCSVC_MOUNT_H 1
#define HAVE_RPCSVC_NIS_H 1
#define HAVE_RPCSVC_YP_PROT_H 1
#define HAVE_RPCSVC_YPCLNT_H 1
#define HAVE_SYS_DIR_H 1
#define HAVE_SYS_ERRNO_H 1
#define HAVE_SYS_FILE_H 1
#define HAVE_SYS_FSTYP_H 1
#define HAVE_SYS_IOCTL_H 1
#define HAVE_SYS_LOCK_H 1
#define HAVE_SYS_MBUF_H 1
#define HAVE_SYS_MMAN_H 1
#define HAVE_SYS_MOUNT_H 1
#define HAVE_SYS_NETCONFIG_H 1
#define HAVE_SYS_PARAM_H 1
#define HAVE_SYS_PROC_H 1
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_SYS_SEMA_H 1
#define HAVE_SYS_SIGNAL_H 1
#define HAVE_SYS_SOCKET_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_SYSCALL_H 1
#define HAVE_SYS_TIME_H 1
#define HAVE_SYS_TIUSER_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_UIO_H 1
#define HAVE_SYS_UTSNAME_H 1
#define HAVE_SYS_VFS_H 1
#define HAVE_SYS_VNODE_H 1
#define HAVE_ASSERT_H 1
#define HAVE_CTYPE_H 1
#define HAVE_ERRNO_H 1
#define HAVE_FCNTL_H 1
#define HAVE_GRP_H 1
#define HAVE_LIBGEN_H 1
#define HAVE_MALLOC_H 1
#define HAVE_MEMORY_H 1
#define HAVE_MNTENT_H 1
#define HAVE_NDBM_H 1
#define HAVE_NETCONFIG_H 1
#define HAVE_NETDB_H 1
#define HAVE_NETDIR_H 1
#define HAVE_NSSWITCH_H 1
#define HAVE_PWD_H 1
#define HAVE_REGEX_H 1
#define HAVE_RESOLV_H 1
#define HAVE_SETJMP_H 1
#define HAVE_SIGNAL_H 1
#define HAVE_STDARG_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STDIO_H 1
#define HAVE_STRING_H 1
#define HAVE_STRINGS_H 1
#define HAVE_SYSLOG_H 1
#define HAVE_TIME_H 1
#define HAVE_TIUSER_H 1
#define HAVE_VARARGS_H 1
#define HAVE_UNISTD_H 1
#define TIME_WITH_SYS_TIME 1
#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_hpux11.h"
#define HAVE_STRUCT_MNTENT 1
#define HAVE_STRUCT_NFS_ARGS 1
#define nfs_args_t struct nfs_args
#define NFS_FH_FIELD fh
#define am_nfs_fh nfs_fh
#define am_nfs_fh3 nfs_fh3
#define GETGROUPS_T gid_t
#define RETSIGTYPE void
#define HAVE_FHANDLE 1
#define MTYPE_TYPE char *
#define MTYPE_PRINTF_TYPE "%s"
#define YP_ORDER_OUTORDER_TYPE unsigned long
#define RECVFROM_FROMLEN_TYPE int
#define AUTH_CREATE_GIDLIST_TYPE gid_t
#define SVC_IN_ARG_TYPE caddr_t
#define cdfs_args_t struct cdfs_args
#define ufs_args_t struct ufs_args
#define XDRPROC_T_TYPE xdrproc_t
#define WORDS_BIGENDIAN 1
#define inline
#define voidp void *
#define HAVE_EXTERN_OPTARG 1
#define HAVE_EXTERN_CLNT_SPCREATEERROR 1
#define HAVE_EXTERN_CLNT_SPERRNO 1
#define HAVE_EXTERN_FREE 1
#define HAVE_EXTERN_GETDTABLESIZE 1
#define HAVE_EXTERN_GETHOSTNAME 1
#define HAVE_EXTERN_GETLOGIN 1
#define HAVE_EXTERN_GETPAGESIZE 1
#define HAVE_EXTERN_GETWD 1
#define HAVE_EXTERN_MKSTEMP 1
#define HAVE_EXTERN_SBRK 1
#define HAVE_EXTERN_SETITIMER 1
#define HAVE_EXTERN_STRCASECMP 1
#define HAVE_EXTERN_STRDUP 1
#define HAVE_EXTERN_STRSTR 1
#define HAVE_EXTERN_UALARM 1
#define HAVE_EXTERN_USLEEP 1
#define HAVE_EXTERN_WAIT3 1
#define HAVE_EXTERN_VSNPRINTF 1
#define HAVE_LONG_FILE_NAMES 1
#define HAVE_UNISTD_H 1
#define HAVE_TRANSPORT_TYPE_TLI 1
#define HAVE_MNTENT_T_MNT_CNODE 1
#define HAVE_MNTENT_T_MNT_TIME 1
#define HAVE_CDFS_ARGS_T_FSPEC 1
#define HAVE_UFS_ARGS_T_FLAGS 1
#define HAVE_UFS_ARGS_T_FSPEC 1
#define HAVE_STRUCT_FHSTATUS_FHS_FH 1
#define HAVE_NFS_ARGS_T_ACDIRMIN 1
#define HAVE_NFS_ARGS_T_ACREGMIN 1
#define HAVE_STRUCT_IFREQ_IFR_ADDR 1
#define HAVE_MAP_FILE 1
#define HAVE_MAP_NIS 1
#define HAVE_MAP_NISPLUS 1
#define HAVE_MAP_PASSWD 1
#define HAVE_MAP_UNION 1
#define HAVE_FS_CDFS 1
#define HAVE_FS_LOFS 1
#define HAVE_FS_NFS 1
#define HAVE_FS_NFS3 1
#define HAVE_FS_UFS 1
#define HAVE_AMU_FS_AUTO 1
#define HAVE_AMU_FS_DIRECT 1
#define HAVE_AMU_FS_TOPLVL 1
#define HAVE_AMU_FS_ERROR 1
#define HAVE_AMU_FS_INHERIT 1
#define HAVE_AMU_FS_PROGRAM 1
#define HAVE_AMU_FS_LINK 1
#define HAVE_AMU_FS_LINKX 1
#define HAVE_AMU_FS_HOST 1
#define HAVE_AMU_FS_NFSX 1
#define HAVE_AMU_FS_NFSL 1
#define HAVE_AMU_FS_UNION 1
#define MOUNT_TYPE_NFS MNTTYPE_NFS
#define MOUNT_TYPE_NFS3 MNTTYPE_NFS3
#define MOUNT_TYPE_UFS MNTTYPE_43
#define MOUNT_TYPE_CDFS MNTTYPE_CDFS
#define MOUNT_TYPE_LOFS MNTTYPE_LOFS
#define MOUNT_TYPE_CACHEFS MNTTYPE_CACHEFS
#define MOUNT_TYPE_IGNORE MNTTYPE_IGNORE
#define MNTTAB_TYPE_NFS "nfs"
#define MNTTAB_TYPE_NFS3 "nfs3"
#define MNTTAB_TYPE_UFS "ufs"
#define MNTTAB_TYPE_CDFS "cdfs"
#define MNTTAB_TYPE_LOFS "lofs"
#define MNTTAB_TYPE_CACHEFS "cachefs"
#define MNTTAB_OPT_ACDIRMAX "acdirmax"
#define MNTTAB_OPT_ACDIRMIN "acdirmin"
#define MNTTAB_OPT_ACREGMAX "acregmax"
#define MNTTAB_OPT_ACREGMIN "acregmin"
#define MNTTAB_OPT_ACTIMEO "actimeo"
#define MNTTAB_OPT_INTR "intr"
#define MNTTAB_OPT_NOAC "noac"
#define MNTTAB_OPT_NOAUTO "noauto"
#define MNTTAB_OPT_NOCTO "nocto"
#define MNTTAB_OPT_NOSUID "nosuid"
#define MNTTAB_OPT_PORT "port"
#define MNTTAB_OPT_RETRANS "retrans"
#define MNTTAB_OPT_RETRY "retry"
#define MNTTAB_OPT_RO "ro"
#define MNTTAB_OPT_RSIZE "rsize"
#define MNTTAB_OPT_RW "rw"
#define MNTTAB_OPT_SOFT "soft"
#define MNTTAB_OPT_SUID "suid"
#define MNTTAB_OPT_TIMEO "timeo"
#define MNTTAB_OPT_WSIZE "wsize"
#define MNT2_GEN_OPT_DATA 0x8
#define MNT2_GEN_OPT_FSS 0x0
#define MNT2_GEN_OPT_NOSUID 0x2
#define MNT2_GEN_OPT_OVERLAY 0x80
#define MNT2_GEN_OPT_QUOTA 0x4
#define MNT2_GEN_OPT_RDONLY 0x1
#define MNT2_NFS_OPT_ACDIRMAX 0x800
#define MNT2_NFS_OPT_ACDIRMIN 0x400
#define MNT2_NFS_OPT_ACREGMAX 0x200
#define MNT2_NFS_OPT_ACREGMIN 0x100
#define MNT2_NFS_OPT_FSNAME 0x1000000
#define MNT2_NFS_OPT_GRPID 0x8000
#define MNT2_NFS_OPT_HOSTNAME 0x20
#define MNT2_NFS_OPT_IGNORE 0x4000000
#define MNT2_NFS_OPT_INT 0x40
#define MNT2_NFS_OPT_KNCONF 0x4000
#define MNT2_NFS_OPT_NOAC 0x80
#define MNT2_NFS_OPT_NOCTO 0x2000
#define MNT2_NFS_OPT_POSIX 0x40000
#define MNT2_NFS_OPT_RETRANS 0x10
#define MNT2_NFS_OPT_RSIZE 0x4
#define MNT2_NFS_OPT_SOFT 0x1
#define MNT2_NFS_OPT_TIMEO 0x8
#define MNT2_NFS_OPT_WSIZE 0x2
#define HIDE_MOUNT_TYPE "ignore"
#define MOUNT_TABLE_ON_FILE 1
#define MNTTAB_FILE_NAME "/etc/mnttab"
